@@ -3,14 +3,33 @@ import matplotlib.cm as cm
 import matplotlib.gridspec as gridspec
 import pandas as pd
 import numpy as np
+import math as math
 from adjustText import adjust_text
 
+import mgt2001.per as per
+import mgt2001.des as des
+import mgt2001.notes as notes
 
-def ori_autolabel(rects):
+
+def geomean(rate):
+    """
+    Result: Will return the geometric mean
+
+    Usage:
+    return_rate = np.array([0.2, 0.1, -0.05])
+    avg_rate = geomean(return_rate)
+    print("geo_mean =", avg_rate)
+    """
+    rate_1 = rate + 1
+    geo_m = math.exp(np.log(rate_1).mean()) - 1
+    return geo_m
+
+
+def ori_autolabel(rects, truncate='{}'):
     """Attach a text label above each bar in *rects*, displaying its height."""
     for rect in rects:
         height = rect.get_height()
-        plt.annotate('{}'.format(height),
+        plt.annotate(truncate.format(height),
                      xy=(rect.get_x() + rect.get_width() / 2, height),
                      xytext=(0, 3),  # 3 points vertical offset
                      textcoords="offset points",
@@ -23,15 +42,24 @@ def autolabel(rects, **kwargs):
     Only *arrowprops* is available right now.
     """
     if "original" in kwargs and kwargs["original"] == True:
-        ori_autolabel(rects)
+        if "truncate" in kwargs:
+            ori_autolabel(rects, kwargs["truncate"])
+            return
+        else:
+            ori_autolabel(rects)
         return
 
     texts = []
     for rect in rects:
         height = rect.get_height()
-        texts.append(plt.text(s='{}'.format(height),
-                              x=(rect.get_x() + rect.get_width() / 2),
-                              y=(height)))
+        if "truncate" in kwargs:
+            texts.append(plt.text(s=kwargs["truncate"].format(height),
+                                  x=(rect.get_x() + rect.get_width() / 2),
+                                  y=(height)))
+        else:
+            texts.append(plt.text(s='{}'.format(height),
+                                  x=(rect.get_x() + rect.get_width() / 2),
+                                  y=(height)))
 
     if "arrowprops" in kwargs:
         adjust_text(texts, arrowprops=kwargs['arrowprops'])
